@@ -17,15 +17,12 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_i_ftp_client.h
- * Globus FTP Client Library
- *
- * $RCSfile: globus_i_ftp_client.h,v $
- * $Revision: 1.50.10.1 $
- * $Date: 2012/06/27 14:49:20 $
+ * @brief Globus FTP Client Library Internals
  */
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
 
-#ifndef GLOBUS_L_INCLUDE_FTP_CLIENT_H
-#define GLOBUS_L_INCLUDE_FTP_CLIENT_H
+#ifndef GLOBUS_I_FTP_CLIENT_H
+#define GLOBUS_I_FTP_CLIENT_H
 
 #include "globus_common.h"
 #include "globus_ftp_client.h"
@@ -37,18 +34,9 @@
 
 #define GLOBUS_L_FTP_CLIENT_CLIENTINFO_APPNAME "libglobus_ftp_client"
 
-#ifndef EXTERN_C_BEGIN
 #ifdef __cplusplus
-#define EXTERN_C_BEGIN extern "C" {
-#define EXTERN_C_END }
-#else
-#define EXTERN_C_BEGIN
-#define EXTERN_C_END
+extern "C" {
 #endif
-#endif
-
-EXTERN_C_BEGIN
-
 
 #ifdef DEBUG_LOCKS
 #define globus_i_ftp_client_handle_lock(handle) \
@@ -138,7 +126,7 @@ do { \
  */
 
 /**
- * The globus_i_ftp_client_operationattr_t is a pointer to this structure type.
+ * @brief The globus_i_ftp_client_operationattr_t is a pointer to this structure type.
  */
 typedef struct globus_i_ftp_client_operationattr_t
 {
@@ -176,7 +164,7 @@ typedef struct globus_i_ftp_client_operationattr_t
 globus_i_ftp_client_operationattr_t;
 
 /**
- * Byte range report.
+ * @brief Byte range report.
  * @ingroup globus_ftp_client_operationattr
  *
  * This structure contains information about a single extent of data
@@ -199,7 +187,7 @@ typedef struct
 globus_i_ftp_client_range_t;
 
 /**
- * Handle attributes.
+ * @brief Handle attributes.
  * @ingroup globus_ftp_client_handleattr
  */
 typedef struct globus_i_ftp_client_handleattr_t
@@ -426,7 +414,7 @@ typedef struct globus_i_ftp_client_url_ent_s
 
 
 /**
- * FTP server features we are interested in. 
+ * @brief FTP server features we are interested in. 
  *
  * Upon a new connection, we will attempt to probe via the SITE HELP
  * and FEAT commands which the server supports. If we can't determine
@@ -488,7 +476,7 @@ char *
 globus_i_ftp_client_find_ssh_client_program();
 
 /**
- * Data connection caching information.
+ * @brief Data connection caching information.
  * @ingroup globus_ftp_client_handle
  * @internal
  *
@@ -520,7 +508,7 @@ typedef struct
 globus_i_ftp_client_data_target_t;
 
 /**
- * FTP Client handle implementation
+ * @brief FTP Client handle implementation
  * @ingroup globus_ftp_client_handle
  * @internal
  *
@@ -684,7 +672,7 @@ typedef struct globus_i_ftp_client_handle_t
 globus_i_ftp_client_handle_t;
 
 /** 
- * FTP Connection State.
+ * @brief FTP Connection State.
  *
  * This type is used to store information about an active FTP control
  * connection. This information includes the FTP control handle, the
@@ -750,7 +738,7 @@ typedef struct globus_i_ftp_client_target_s
 } globus_i_ftp_client_target_t;
 
 /**
- * URL caching support structure.
+ * @brief URL caching support structure.
  *
  * This structure is used to implement the cache of URLs. When a
  * target is needed, the client library first checks the handle's
@@ -780,7 +768,7 @@ typedef struct
 globus_i_ftp_client_cache_entry_t;
 
 /**
- * Restart information management.
+ * @brief Restart information management.
  */
 typedef struct globus_i_ftp_client_restart_s
 {
@@ -795,7 +783,7 @@ typedef struct globus_i_ftp_client_restart_s
 globus_i_ftp_client_restart_t;
 
 /**
- * FTP Client Plugin.
+ * @brief FTP Client Plugin.
  * @ingroup globus_ftp_client_plugins
  *
  * Each plugin implementation should define a method for initializing
@@ -1401,8 +1389,8 @@ globus_i_ftp_client_wrap_ftp_error(
 
 #endif
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
-#endif /* GLOBUS_L_INCLUDE_FTP_CLIENT_H */
-
-#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
+#endif /* GLOBUS_I_FTP_CLIENT_H */
